@@ -37,8 +37,8 @@ add it before instantiating the AMPL object with:
 
 Or, if you are using amplpy.modules, do the following:
 
-    from amplpy import AMPL, tools
-    tools.modules.load()
+    from amplpy import AMPL, modules
+    modules.load()
     ampl = AMPL()
 """
 
