@@ -19,9 +19,13 @@ class Table;
 namespace internal {
 
 template <class EntityClass>
-struct EntityMap_RefPointer {
+struct EntityMapRefPointer {
+  typedef typename std::map<std::string, EntityClass *>::const_iterator
+      iterator_type;
   std::size_t count_;
-  typename std::map<std::string, EntityClass *>::const_iterator it_;
+  iterator_type it_;
+  EntityMapRefPointer(size_t count, const iterator_type &it)
+      : count_(count), it_(it) {}
 };
 
 template <class EntityClass>
@@ -33,126 +37,115 @@ class Set;
 class Constraint;
 class Table;
 
-typedef std::map<std::string, Variable *>::iterator VariableIterator;
-typedef std::map<std::string, Constraint *>::iterator ConstraintIterator;
-typedef std::map<std::string, Set *>::iterator SetIterator;
-typedef std::map<std::string, Objective *>::iterator ObjectiveIterator;
-typedef std::map<std::string, Parameter *>::iterator ParameterIterator;
-typedef std::map<std::string, Table *>::iterator TableIterator;
-
 extern "C" {
 AMPLAPI Variable *AMPL_EntityMap_Variable_get(EntityMap<Variable> *impl,
                                               const char *name);
 AMPLAPI std::size_t AMPL_EntityMap_Variable_size(EntityMap<Variable> *impl);
-AMPLAPI EntityMap_RefPointer<Variable> *AMPL_EntityMap_iterator_Variable_begin(
+AMPLAPI EntityMapRefPointer<Variable> *AMPL_EntityMap_iterator_Variable_begin(
     EntityMap<Variable> *impl, ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Variable> *AMPL_EntityMap_iterator_Variable_end(
+AMPLAPI EntityMapRefPointer<Variable> *AMPL_EntityMap_iterator_Variable_end(
     EntityMap<Variable> *impl, ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Variable> *AMPL_EntityMap_iterator_Variable_find(
+AMPLAPI EntityMapRefPointer<Variable> *AMPL_EntityMap_iterator_Variable_find(
     EntityMap<Variable> *impl, const char *name, ErrorInformation *errorInfo);
 AMPLAPI bool AMPL_EntityMap_iterator_Variable_equal(
-    EntityMap_RefPointer<Variable> *it1, EntityMap_RefPointer<Variable> *it2);
+    EntityMapRefPointer<Variable> *it1, EntityMapRefPointer<Variable> *it2);
 AMPLAPI void AMPL_EntityMap_iterator_Variable_delete(
-    EntityMap_RefPointer<Variable> *it);
+    EntityMapRefPointer<Variable> *it);
 AMPLAPI void AMPL_EntityMap_iterator_Variable_increment(
-    EntityMap_RefPointer<Variable> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Variable> *it, ErrorInformation *errorInfo);
 AMPLAPI Variable *AMPL_EntityMap_iterator_Variable_second(
-    EntityMap_RefPointer<Variable> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Variable> *it, ErrorInformation *errorInfo);
 
 AMPLAPI Objective *AMPL_EntityMap_Objective_get(EntityMap<Objective> *impl,
                                                 const char *name);
 AMPLAPI std::size_t AMPL_EntityMap_Objective_size(EntityMap<Objective> *impl);
-AMPLAPI EntityMap_RefPointer<Objective>
-    *AMPL_EntityMap_iterator_Objective_begin(EntityMap<Objective> *impl,
-                                             ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Objective> *AMPL_EntityMap_iterator_Objective_end(
+AMPLAPI EntityMapRefPointer<Objective> *AMPL_EntityMap_iterator_Objective_begin(
     EntityMap<Objective> *impl, ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Objective> *AMPL_EntityMap_iterator_Objective_find(
+AMPLAPI EntityMapRefPointer<Objective> *AMPL_EntityMap_iterator_Objective_end(
+    EntityMap<Objective> *impl, ErrorInformation *errorInfo);
+AMPLAPI EntityMapRefPointer<Objective> *AMPL_EntityMap_iterator_Objective_find(
     EntityMap<Objective> *impl, const char *name, ErrorInformation *errorInfo);
 AMPLAPI bool AMPL_EntityMap_iterator_Objective_equal(
-    EntityMap_RefPointer<Objective> *it1, EntityMap_RefPointer<Objective> *it2);
+    EntityMapRefPointer<Objective> *it1, EntityMapRefPointer<Objective> *it2);
 AMPLAPI void AMPL_EntityMap_iterator_Objective_delete(
-    EntityMap_RefPointer<Objective> *it);
+    EntityMapRefPointer<Objective> *it);
 AMPLAPI void AMPL_EntityMap_iterator_Objective_increment(
-    EntityMap_RefPointer<Objective> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Objective> *it, ErrorInformation *errorInfo);
 AMPLAPI Objective *AMPL_EntityMap_iterator_Objective_second(
-    EntityMap_RefPointer<Objective> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Objective> *it, ErrorInformation *errorInfo);
 
 AMPLAPI Set *AMPL_EntityMap_Set_get(EntityMap<Set> *impl, const char *name);
 AMPLAPI std::size_t AMPL_EntityMap_Set_size(EntityMap<Set> *impl);
-AMPLAPI EntityMap_RefPointer<Set> *AMPL_EntityMap_iterator_Set_begin(
+AMPLAPI EntityMapRefPointer<Set> *AMPL_EntityMap_iterator_Set_begin(
     EntityMap<Set> *impl, ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Set> *AMPL_EntityMap_iterator_Set_end(
+AMPLAPI EntityMapRefPointer<Set> *AMPL_EntityMap_iterator_Set_end(
     EntityMap<Set> *impl, ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Set> *AMPL_EntityMap_iterator_Set_find(
+AMPLAPI EntityMapRefPointer<Set> *AMPL_EntityMap_iterator_Set_find(
     EntityMap<Set> *impl, const char *name, ErrorInformation *errorInfo);
-AMPLAPI bool AMPL_EntityMap_iterator_Set_equal(EntityMap_RefPointer<Set> *it1,
-                                               EntityMap_RefPointer<Set> *it2);
-AMPLAPI void AMPL_EntityMap_iterator_Set_delete(EntityMap_RefPointer<Set> *it);
-AMPLAPI void AMPL_EntityMap_iterator_Set_increment(
-    EntityMap_RefPointer<Set> *it, ErrorInformation *errorInfo);
-AMPLAPI Set *AMPL_EntityMap_iterator_Set_second(EntityMap_RefPointer<Set> *it,
+AMPLAPI bool AMPL_EntityMap_iterator_Set_equal(EntityMapRefPointer<Set> *it1,
+                                               EntityMapRefPointer<Set> *it2);
+AMPLAPI void AMPL_EntityMap_iterator_Set_delete(EntityMapRefPointer<Set> *it);
+AMPLAPI void AMPL_EntityMap_iterator_Set_increment(EntityMapRefPointer<Set> *it,
+                                                   ErrorInformation *errorInfo);
+AMPLAPI Set *AMPL_EntityMap_iterator_Set_second(EntityMapRefPointer<Set> *it,
                                                 ErrorInformation *errorInfo);
 
 AMPLAPI Parameter *AMPL_EntityMap_Parameter_get(EntityMap<Parameter> *impl,
                                                 const char *name);
 AMPLAPI std::size_t AMPL_EntityMap_Parameter_size(EntityMap<Parameter> *impl);
-AMPLAPI EntityMap_RefPointer<Parameter>
-    *AMPL_EntityMap_iterator_Parameter_begin(EntityMap<Parameter> *impl,
-                                             ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Parameter> *AMPL_EntityMap_iterator_Parameter_end(
+AMPLAPI EntityMapRefPointer<Parameter> *AMPL_EntityMap_iterator_Parameter_begin(
     EntityMap<Parameter> *impl, ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Parameter> *AMPL_EntityMap_iterator_Parameter_find(
+AMPLAPI EntityMapRefPointer<Parameter> *AMPL_EntityMap_iterator_Parameter_end(
+    EntityMap<Parameter> *impl, ErrorInformation *errorInfo);
+AMPLAPI EntityMapRefPointer<Parameter> *AMPL_EntityMap_iterator_Parameter_find(
     EntityMap<Parameter> *impl, const char *name, ErrorInformation *errorInfo);
 AMPLAPI bool AMPL_EntityMap_iterator_Parameter_equal(
-    EntityMap_RefPointer<Parameter> *it1, EntityMap_RefPointer<Parameter> *it2);
+    EntityMapRefPointer<Parameter> *it1, EntityMapRefPointer<Parameter> *it2);
 AMPLAPI void AMPL_EntityMap_iterator_Parameter_delete(
-    EntityMap_RefPointer<Parameter> *it);
+    EntityMapRefPointer<Parameter> *it);
 AMPLAPI void AMPL_EntityMap_iterator_Parameter_increment(
-    EntityMap_RefPointer<Parameter> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Parameter> *it, ErrorInformation *errorInfo);
 AMPLAPI Parameter *AMPL_EntityMap_iterator_Parameter_second(
-    EntityMap_RefPointer<Parameter> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Parameter> *it, ErrorInformation *errorInfo);
 
 AMPLAPI Table *AMPL_EntityMap_Table_get(EntityMap<Table> *impl,
                                         const char *name);
 AMPLAPI std::size_t AMPL_EntityMap_Table_size(EntityMap<Table> *impl);
-AMPLAPI EntityMap_RefPointer<Table> *AMPL_EntityMap_iterator_Table_begin(
+AMPLAPI EntityMapRefPointer<Table> *AMPL_EntityMap_iterator_Table_begin(
     EntityMap<Table> *impl, ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Table> *AMPL_EntityMap_iterator_Table_end(
+AMPLAPI EntityMapRefPointer<Table> *AMPL_EntityMap_iterator_Table_end(
     EntityMap<Table> *impl, ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Table> *AMPL_EntityMap_iterator_Table_find(
+AMPLAPI EntityMapRefPointer<Table> *AMPL_EntityMap_iterator_Table_find(
     EntityMap<Table> *impl, const char *name, ErrorInformation *errorInfo);
 AMPLAPI bool AMPL_EntityMap_iterator_Table_equal(
-    EntityMap_RefPointer<Table> *it1, EntityMap_RefPointer<Table> *it2);
+    EntityMapRefPointer<Table> *it1, EntityMapRefPointer<Table> *it2);
 AMPLAPI void AMPL_EntityMap_iterator_Table_delete(
-    EntityMap_RefPointer<Table> *it);
+    EntityMapRefPointer<Table> *it);
 AMPLAPI void AMPL_EntityMap_iterator_Table_increment(
-    EntityMap_RefPointer<Table> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Table> *it, ErrorInformation *errorInfo);
 AMPLAPI Table *AMPL_EntityMap_iterator_Table_second(
-    EntityMap_RefPointer<Table> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Table> *it, ErrorInformation *errorInfo);
 
 AMPLAPI Constraint *AMPL_EntityMap_Constraint_get(EntityMap<Constraint> *impl,
                                                   const char *name);
 AMPLAPI std::size_t AMPL_EntityMap_Constraint_size(EntityMap<Constraint> *impl);
-AMPLAPI EntityMap_RefPointer<Constraint>
+AMPLAPI EntityMapRefPointer<Constraint>
     *AMPL_EntityMap_iterator_Constraint_begin(EntityMap<Constraint> *impl,
                                               ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Constraint>
-    *AMPL_EntityMap_iterator_Constraint_end(EntityMap<Constraint> *impl,
-                                            ErrorInformation *errorInfo);
-AMPLAPI EntityMap_RefPointer<Constraint>
+AMPLAPI EntityMapRefPointer<Constraint> *AMPL_EntityMap_iterator_Constraint_end(
+    EntityMap<Constraint> *impl, ErrorInformation *errorInfo);
+AMPLAPI EntityMapRefPointer<Constraint>
     *AMPL_EntityMap_iterator_Constraint_find(EntityMap<Constraint> *impl,
                                              const char *name,
                                              ErrorInformation *errorInfo);
 AMPLAPI bool AMPL_EntityMap_iterator_Constraint_equal(
-    EntityMap_RefPointer<Constraint> *it1,
-    EntityMap_RefPointer<Constraint> *it2);
+    EntityMapRefPointer<Constraint> *it1, EntityMapRefPointer<Constraint> *it2);
 AMPLAPI void AMPL_EntityMap_iterator_Constraint_delete(
-    EntityMap_RefPointer<Constraint> *it);
+    EntityMapRefPointer<Constraint> *it);
 AMPLAPI void AMPL_EntityMap_iterator_Constraint_increment(
-    EntityMap_RefPointer<Constraint> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Constraint> *it, ErrorInformation *errorInfo);
 AMPLAPI Constraint *AMPL_EntityMap_iterator_Constraint_second(
-    EntityMap_RefPointer<Constraint> *it, ErrorInformation *errorInfo);
+    EntityMapRefPointer<Constraint> *it, ErrorInformation *errorInfo);
 }  // C Linkage
 
 template <typename EntityPrivate>
@@ -168,29 +161,29 @@ struct EntityFunctions<ampl::Variable> {
     return AMPL_EntityMap_Variable_size(impl);
   }
 
-  static internal::EntityMap_RefPointer<Variable> *begin(
+  static internal::EntityMapRefPointer<Variable> *begin(
       EntityMap<Variable> *impl) {
     return AMPL_EntityMap_iterator_Variable_begin(impl, ErrorInfo());
   }
-  static internal::EntityMap_RefPointer<Variable> *end(
+  static internal::EntityMapRefPointer<Variable> *end(
       EntityMap<Variable> *impl) {
     return AMPL_EntityMap_iterator_Variable_end(impl, ErrorInfo());
   }
-  static internal::EntityMap_RefPointer<Variable> *find(
+  static internal::EntityMapRefPointer<Variable> *find(
       EntityMap<Variable> *impl, const char *name) {
     return AMPL_EntityMap_iterator_Variable_find(impl, name, ErrorInfo());
   }
-  static bool equal(internal::EntityMap_RefPointer<Variable> *it1,
-                    internal::EntityMap_RefPointer<Variable> *it2) {
+  static bool equal(internal::EntityMapRefPointer<Variable> *it1,
+                    internal::EntityMapRefPointer<Variable> *it2) {
     return AMPL_EntityMap_iterator_Variable_equal(it1, it2);
   }
-  static void delete_iterator(internal::EntityMap_RefPointer<Variable> *it) {
+  static void delete_iterator(internal::EntityMapRefPointer<Variable> *it) {
     AMPL_EntityMap_iterator_Variable_delete(it);
   }
-  static void increment(internal::EntityMap_RefPointer<Variable> *it) {
+  static void increment(internal::EntityMapRefPointer<Variable> *it) {
     AMPL_EntityMap_iterator_Variable_increment(it, ErrorInfo());
   }
-  static Variable *second(internal::EntityMap_RefPointer<Variable> *it) {
+  static Variable *second(internal::EntityMapRefPointer<Variable> *it) {
     return AMPL_EntityMap_iterator_Variable_second(it, ErrorInfo());
   }
 };
@@ -203,27 +196,27 @@ struct EntityFunctions<ampl::Constraint> {
   static std::size_t size(EntityMap<Constraint> *impl) {
     return AMPL_EntityMap_Constraint_size(impl);
   }
-  static EntityMap_RefPointer<Constraint> *begin(EntityMap<Constraint> *impl) {
+  static EntityMapRefPointer<Constraint> *begin(EntityMap<Constraint> *impl) {
     return AMPL_EntityMap_iterator_Constraint_begin(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Constraint> *end(EntityMap<Constraint> *impl) {
+  static EntityMapRefPointer<Constraint> *end(EntityMap<Constraint> *impl) {
     return AMPL_EntityMap_iterator_Constraint_end(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Constraint> *find(EntityMap<Constraint> *impl,
-                                                const char *name) {
+  static EntityMapRefPointer<Constraint> *find(EntityMap<Constraint> *impl,
+                                               const char *name) {
     return AMPL_EntityMap_iterator_Constraint_find(impl, name, ErrorInfo());
   }
-  static bool equal(EntityMap_RefPointer<Constraint> *it1,
-                    EntityMap_RefPointer<Constraint> *it2) {
+  static bool equal(EntityMapRefPointer<Constraint> *it1,
+                    EntityMapRefPointer<Constraint> *it2) {
     return AMPL_EntityMap_iterator_Constraint_equal(it1, it2);
   }
-  static void delete_iterator(EntityMap_RefPointer<Constraint> *it) {
+  static void delete_iterator(EntityMapRefPointer<Constraint> *it) {
     AMPL_EntityMap_iterator_Constraint_delete(it);
   }
-  static void increment(EntityMap_RefPointer<Constraint> *it) {
+  static void increment(EntityMapRefPointer<Constraint> *it) {
     AMPL_EntityMap_iterator_Constraint_increment(it, ErrorInfo());
   }
-  static Constraint *second(internal::EntityMap_RefPointer<Constraint> *it) {
+  static Constraint *second(internal::EntityMapRefPointer<Constraint> *it) {
     return AMPL_EntityMap_iterator_Constraint_second(it, ErrorInfo());
   }
 };
@@ -236,27 +229,27 @@ struct EntityFunctions<ampl::Parameter> {
   static std::size_t size(EntityMap<Parameter> *impl) {
     return AMPL_EntityMap_Parameter_size(impl);
   }
-  static EntityMap_RefPointer<Parameter> *begin(EntityMap<Parameter> *impl) {
+  static EntityMapRefPointer<Parameter> *begin(EntityMap<Parameter> *impl) {
     return AMPL_EntityMap_iterator_Parameter_begin(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Parameter> *end(EntityMap<Parameter> *impl) {
+  static EntityMapRefPointer<Parameter> *end(EntityMap<Parameter> *impl) {
     return AMPL_EntityMap_iterator_Parameter_end(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Parameter> *find(EntityMap<Parameter> *impl,
-                                               const char *name) {
+  static EntityMapRefPointer<Parameter> *find(EntityMap<Parameter> *impl,
+                                              const char *name) {
     return AMPL_EntityMap_iterator_Parameter_find(impl, name, ErrorInfo());
   }
-  static bool equal(EntityMap_RefPointer<Parameter> *it1,
-                    EntityMap_RefPointer<Parameter> *it2) {
+  static bool equal(EntityMapRefPointer<Parameter> *it1,
+                    EntityMapRefPointer<Parameter> *it2) {
     return AMPL_EntityMap_iterator_Parameter_equal(it1, it2);
   }
-  static void delete_iterator(EntityMap_RefPointer<Parameter> *it) {
+  static void delete_iterator(EntityMapRefPointer<Parameter> *it) {
     AMPL_EntityMap_iterator_Parameter_delete(it);
   }
-  static void increment(EntityMap_RefPointer<Parameter> *it) {
+  static void increment(EntityMapRefPointer<Parameter> *it) {
     AMPL_EntityMap_iterator_Parameter_increment(it, ErrorInfo());
   }
-  static Parameter *second(internal::EntityMap_RefPointer<Parameter> *it) {
+  static Parameter *second(internal::EntityMapRefPointer<Parameter> *it) {
     return AMPL_EntityMap_iterator_Parameter_second(it, ErrorInfo());
   }
 };
@@ -269,27 +262,27 @@ struct EntityFunctions<ampl::Set> {
   static std::size_t size(EntityMap<Set> *impl) {
     return AMPL_EntityMap_Set_size(impl);
   }
-  static EntityMap_RefPointer<Set> *begin(EntityMap<Set> *impl) {
+  static EntityMapRefPointer<Set> *begin(EntityMap<Set> *impl) {
     return AMPL_EntityMap_iterator_Set_begin(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Set> *end(EntityMap<Set> *impl) {
+  static EntityMapRefPointer<Set> *end(EntityMap<Set> *impl) {
     return AMPL_EntityMap_iterator_Set_end(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Set> *find(EntityMap<Set> *impl,
-                                         const char *name) {
+  static EntityMapRefPointer<Set> *find(EntityMap<Set> *impl,
+                                        const char *name) {
     return AMPL_EntityMap_iterator_Set_find(impl, name, ErrorInfo());
   }
-  static bool equal(EntityMap_RefPointer<Set> *it1,
-                    EntityMap_RefPointer<Set> *it2) {
+  static bool equal(EntityMapRefPointer<Set> *it1,
+                    EntityMapRefPointer<Set> *it2) {
     return AMPL_EntityMap_iterator_Set_equal(it1, it2);
   }
-  static void delete_iterator(EntityMap_RefPointer<Set> *it) {
+  static void delete_iterator(EntityMapRefPointer<Set> *it) {
     AMPL_EntityMap_iterator_Set_delete(it);
   }
-  static void increment(EntityMap_RefPointer<Set> *it) {
+  static void increment(EntityMapRefPointer<Set> *it) {
     AMPL_EntityMap_iterator_Set_increment(it, ErrorInfo());
   }
-  static Set *second(internal::EntityMap_RefPointer<Set> *it) {
+  static Set *second(internal::EntityMapRefPointer<Set> *it) {
     return AMPL_EntityMap_iterator_Set_second(it, ErrorInfo());
   }
 };
@@ -302,27 +295,27 @@ struct EntityFunctions<ampl::Objective> {
   static std::size_t size(EntityMap<Objective> *impl) {
     return AMPL_EntityMap_Objective_size(impl);
   }
-  static EntityMap_RefPointer<Objective> *begin(EntityMap<Objective> *impl) {
+  static EntityMapRefPointer<Objective> *begin(EntityMap<Objective> *impl) {
     return AMPL_EntityMap_iterator_Objective_begin(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Objective> *end(EntityMap<Objective> *impl) {
+  static EntityMapRefPointer<Objective> *end(EntityMap<Objective> *impl) {
     return AMPL_EntityMap_iterator_Objective_end(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Objective> *find(EntityMap<Objective> *impl,
-                                               const char *name) {
+  static EntityMapRefPointer<Objective> *find(EntityMap<Objective> *impl,
+                                              const char *name) {
     return AMPL_EntityMap_iterator_Objective_find(impl, name, ErrorInfo());
   }
-  static bool equal(EntityMap_RefPointer<Objective> *it1,
-                    EntityMap_RefPointer<Objective> *it2) {
+  static bool equal(EntityMapRefPointer<Objective> *it1,
+                    EntityMapRefPointer<Objective> *it2) {
     return AMPL_EntityMap_iterator_Objective_equal(it1, it2);
   }
-  static void delete_iterator(EntityMap_RefPointer<Objective> *it) {
+  static void delete_iterator(EntityMapRefPointer<Objective> *it) {
     AMPL_EntityMap_iterator_Objective_delete(it);
   }
-  static void increment(EntityMap_RefPointer<Objective> *it) {
+  static void increment(EntityMapRefPointer<Objective> *it) {
     AMPL_EntityMap_iterator_Objective_increment(it, ErrorInfo());
   }
-  static Objective *second(internal::EntityMap_RefPointer<Objective> *it) {
+  static Objective *second(internal::EntityMapRefPointer<Objective> *it) {
     return AMPL_EntityMap_iterator_Objective_second(it, ErrorInfo());
   }
 };
@@ -335,27 +328,27 @@ struct EntityFunctions<ampl::Table> {
   static std::size_t size(EntityMap<Table> *impl) {
     return AMPL_EntityMap_Table_size(impl);
   }
-  static EntityMap_RefPointer<Table> *begin(EntityMap<Table> *impl) {
+  static EntityMapRefPointer<Table> *begin(EntityMap<Table> *impl) {
     return AMPL_EntityMap_iterator_Table_begin(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Table> *end(EntityMap<Table> *impl) {
+  static EntityMapRefPointer<Table> *end(EntityMap<Table> *impl) {
     return AMPL_EntityMap_iterator_Table_end(impl, ErrorInfo());
   }
-  static EntityMap_RefPointer<Table> *find(EntityMap<Table> *impl,
-                                           const char *name) {
+  static EntityMapRefPointer<Table> *find(EntityMap<Table> *impl,
+                                          const char *name) {
     return AMPL_EntityMap_iterator_Table_find(impl, name, ErrorInfo());
   }
-  static bool equal(EntityMap_RefPointer<Table> *it1,
-                    EntityMap_RefPointer<Table> *it2) {
+  static bool equal(EntityMapRefPointer<Table> *it1,
+                    EntityMapRefPointer<Table> *it2) {
     return AMPL_EntityMap_iterator_Table_equal(it1, it2);
   }
-  static void delete_iterator(EntityMap_RefPointer<Table> *it) {
+  static void delete_iterator(EntityMapRefPointer<Table> *it) {
     AMPL_EntityMap_iterator_Table_delete(it);
   }
-  static void increment(EntityMap_RefPointer<Table> *it) {
+  static void increment(EntityMapRefPointer<Table> *it) {
     AMPL_EntityMap_iterator_Table_increment(it, ErrorInfo());
   }
-  static Table *second(internal::EntityMap_RefPointer<Table> *it) {
+  static Table *second(internal::EntityMapRefPointer<Table> *it) {
     return AMPL_EntityMap_iterator_Table_second(it, ErrorInfo());
   }
 };
