@@ -464,6 +464,11 @@ class SetInstance : public BasicInstance<internal::SetInstance> {
     the collection
     */
     iterator end() const { return iterator(members_ + size_); }
+
+    /**
+    Returns the size of the collection
+    */
+    std::size_t size() const { return size_; }
   };
 
   /**
