@@ -155,6 +155,8 @@ class BasicVariant {
   */
   explicit BasicVariant(internal::Variant var) : impl_(var) {}
 
+  explicit BasicVariant(internal::Variant* var) : impl_(*var) {}
+
   /**
   Default constructor, creates an empty variant
   */
@@ -264,6 +266,8 @@ class BasicVariant {
   */
   internal::Variant impl() const { return impl_; }
 
+  internal::Variant* impl_ptr() { return &impl_; }
+
   /**
   Return an %AMPL like representation of this variant. String variants are
   single-quoted, numeric are not.
