@@ -19,6 +19,8 @@ REAL_ROOT = os.environ.get("REAL_ROOT", None)
 class TestBase(unittest.TestCase):
     def setUp(self):
         print("Method:", self._testMethodName)
+        os.environ["solver"] = "highs"
+        os.environ["highs_options"] = "outlev=1"
         self.ampl = amplpy.AMPL()
         self.dirpath = tempfile.mkdtemp()
 
